@@ -41,7 +41,7 @@ bool KBlocksSound::loadTheme(const QString &themeFile)
     }
 
     QString themeMoveSound;
-    if (theme.themeProperty("Sound_Block_Move") != "") {
+    if (!theme.themeProperty("Sound_Block_Move").isEmpty()) {
         themeMoveSound = theme.prefix() + theme.themeProperty("Sound_Block_Move");
     } else {
         themeMoveSound = QStandardPaths::locate(
@@ -49,7 +49,7 @@ bool KBlocksSound::loadTheme(const QString &themeFile)
     }
     
     QString themeFallSound;
-    if (theme.themeProperty("Sound_Block_Fall") != "") {
+    if (!theme.themeProperty("Sound_Block_Fall").isEmpty()) {
         themeFallSound = theme.prefix() + theme.themeProperty("Sound_Block_Fall");
     } else {
         themeFallSound = QStandardPaths::locate(
@@ -57,7 +57,7 @@ bool KBlocksSound::loadTheme(const QString &themeFile)
     }
     
     QString themeRemoveSound;
-    if (theme.themeProperty("Sound_Block_Remove") != "") {
+    if (!theme.themeProperty("Sound_Block_Remove").isEmpty()) {
         themeRemoveSound = theme.prefix() + theme.themeProperty("Sound_Block_Remove");
     } else {
         themeRemoveSound = QStandardPaths::locate(
